# Django OpenID Connect Provider

![Test](https://github.com/sawadashota/django-oidc-provider/workflows/Test/badge.svg)

## About OpenID

OpenID Connect is a simple identity layer on top of the OAuth 2.0 protocol, which allows computing clients to verify the identity of an end-user based on the authentication performed by an authorization server, as well as to obtain basic profile information about the end-user in an interoperable and REST-like manner. Like [Google](https://developers.google.com/identity/protocols/OpenIDConnect) for example.

## About the package

`django-oidc-provider2` can help you providing out of the box all the endpoints, data and logic needed to add OpenID Connect (and OAuth2) capabilities to your Django projects.

Support for Python 3.9. Also latest versions of django.

[Read documentation for more info.](https://django-oidc-provider2.readthedocs.org/)

[Do you want to contribute? Please read this.](https://django-oidc-provider2.readthedocs.io/en/latest/sections/contribute.html)
